package com.iamberry.wechat.face.wechat;

import java.util.List;

import com.iamberry.wechat.core.entity.wx.KeyWord;
import com.iamberry.wechat.core.entity.wx.PagingDTO;

public interface KeyWordService {
	
	public KeyWord getById(Long keyServiceNo);

	public List<KeyWord> selectKeyList(String pubNo,String word, Integer pageNO, Integer pageSize) throws Exception;
	
	public Integer selectKeyListCount(String pubNo, String word, Integer pageSize);
	
	/**
	 * 批量删除
	 * @param keyWord
	 */
	public Integer batchDelKeyWordById(List<Integer> delIdList);
	
	/**
	 * 单个删除
	 * @param keyWord
	 */
	public Integer deleteKeyWordById(Long id);
	
	void insert(KeyWord keyWord);
	
	void updateByPrimaryKey(KeyWord keyword);
	
	public int getPageNum(String pubNo, int selectNum);

	public List<KeyWord> getBypubNoAndPageNo(PagingDTO pdto);

	public KeyWord getByKeyWord(String keyword);
}
